@@ -44,7 +44,6 @@ const TorrentFilter TorrentFilter::InactiveTorrent(TorrentFilter::Inactive);
 const TorrentFilter TorrentFilter::ErroredTorrent(TorrentFilter::Errored);
 
 using BitTorrent::TorrentHandle;
-using BitTorrent::TorrentState;
 
 TorrentFilter::TorrentFilter()
     : m_type(All)
@@ -174,19 +173,22 @@ bool TorrentFilter::matchState(const BitTorrent::TorrentHandle *const torrent) c
 bool TorrentFilter::matchHash(const BitTorrent::TorrentHandle *const torrent) const
 {
     if (m_hashSet == AnyHash) return true;
-    else return m_hashSet.contains(torrent->hash());
+
+    return m_hashSet.contains(torrent->hash());
 }
 
 bool TorrentFilter::matchCategory(const BitTorrent::TorrentHandle *const torrent) const
 {
     if (m_category.isNull()) return true;
-    else return (torrent->belongsToCategory(m_category));
+
+    return (torrent->belongsToCategory(m_category));
 }
 
 bool TorrentFilter::matchTag(const BitTorrent::TorrentHandle *const torrent) const
 {
     // Empty tag is a special value to indicate we're filtering for untagged torrents.
     if (m_tag.isNull()) return true;
-    else if (m_tag.isEmpty()) return torrent->tags().isEmpty();
-    else return (torrent->hasTag(m_tag));
+    if (m_tag.isEmpty()) return torrent->tags().isEmpty();
+
+    return (torrent->hasTag(m_tag));
 }
