@@ -30,15 +30,16 @@
 #define CATEGORYFILTERMODEL_H
 
 #include <QAbstractItemModel>
-#include <QModelIndex>
+
+class QModelIndex;
+
+class CategoryModelItem;
 
 namespace BitTorrent
 {
     class TorrentHandle;
 }
 
-class CategoryModelItem;
-
 class CategoryFilterModel : public QAbstractItemModel
 {
     Q_OBJECT
@@ -49,13 +50,13 @@ public:
 
     static bool isSpecialItem(const QModelIndex &index);
 
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = {}) const override;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     Qt::ItemFlags flags(const QModelIndex &index) const override;
     QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex index(int row, int column, const QModelIndex &parent = {}) const override;
     QModelIndex parent(const QModelIndex &index) const override;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int rowCount(const QModelIndex &parent = {}) const override;
 
     QModelIndex index(const QString &categoryName) const;
     QString categoryName(const QModelIndex &index) const;
