@@ -31,12 +31,12 @@
 
 #include <QObject>
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 // Require Mac OS X >= 10.5
 #include <IOKit/pwr_mgt/IOPMLib.h>
 #endif
 
-#if (defined(Q_OS_UNIX) && !defined(Q_OS_MAC)) && defined(QT_DBUS_LIB)
+#if (defined(Q_OS_UNIX) && !defined(Q_OS_MACOS)) && defined(QT_DBUS_LIB)
 // Require DBus
 class PowerManagementInhibitor;
 #endif
@@ -57,10 +57,10 @@ private:
   void setBusy();
   void setIdle();
 
-#if (defined(Q_OS_UNIX) && !defined(Q_OS_MAC)) && defined(QT_DBUS_LIB)
+#if (defined(Q_OS_UNIX) && !defined(Q_OS_MACOS)) && defined(QT_DBUS_LIB)
   PowerManagementInhibitor *m_inhibitor;
 #endif
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
   IOPMAssertionID m_assertionID;
 #endif
 };
